//-----------------------------------------
// LScript Modeler template
//
// Copyright 2005 Michael Green
// MikesLscripts@shortbutpurple.fsnet.co.uk
//

myversion=1.1;

//V1.1
// fixed bug and made generic, to work in both modeler or as a generic plugin.

//V1
// First full version!

@version 2.2
@warnings
@script modeler
// global values go here

main
{
    // requester code goes here
    myfilename=globalrecall("MGMTLExportFilename","*.mtl");
    mylum=globalrecall("MGMTLExportLum",1).asInt();


    reqbegin("MGMTLExporter ver:"+myversion);

    c0 = ctlfilename("Save MTL to:",myfilename,30,0);
    c1 = ctlchoice("Use as Specular",1,@"Specular","Reflectivity"@);
    c2 = ctlcheckbox("Assign Ambient to Luminosity",mylum);

    return if !reqpost();

    // get requester control values here
    myfilename=getvalue(c0);
    mychoice=getvalue(c1);
    mylum=getvalue(c2);
    reqend();

    // processing code goes here
    if(myfilename)
    {
        globalstore("MGMTLExportFilename",myfilename);
        globalstore("MGMTLExportLum",mylum);
        writemtl(myfilename,mychoice,mylum);
        info("MTL exported");
    }

}


writemtl:pfilename,pchoice,plum
{
    pfile=File(pfilename,"w");

    pfile.writeln(STRING,"#################################################");
    pfile.writeln(STRING,"##             MTL File created by             ##");
    pfile.writeln(STRING,"##                Michael Green                ##");
    pfile.writeln(STRING,"##      Lscripts@shortbutpurple.fsnet.co.uk    ##");
    pfile.writeln(STRING,"#################################################");

//debug();

    mymesh=Mesh(0);
    mysurfnames=Surface(mymesh);

    for(i=1;i<=mysurfnames.size();i++)
    {
        pfile.writeln(STRING," ");

        myfullname=mysurfnames[i];
        mysurf=Surface(mymesh,myfullname);
        mynewname=replacespaces(myfullname);

        mystring="newmtl "+mynewname;
        pfile.writeln(STRING,mystring);
// colour
        myvalue=mysurf.getValue(SURFCOLR);
        mystring="Kd "+myvalue.x.asStr()+" "+myvalue.y.asStr()+" "+myvalue.z.asStr();
        pfile.writeln(STRING,mystring);
// ambient
        myvalue=mysurf.getValue(SURFLUMI);
        mystring="Ka "+myvalue.asStr();
        pfile.writeln(STRING,mystring);
// Specular
        if(pchoice==1)
            myvalue=mysurf.getValue(SURFSPEC);
        else
            myvalue=mysurf.getValue(SURFREFL);
        mystring="Ks "+myvalue.asStr();
        pfile.writeln(STRING,mystring);
// Glossiness
        myvalue=round(100*mysurf.getValue(SURFGLOS),0);
        mystring="Ns "+myvalue.asStr();
        pfile.writeln(STRING,mystring);
// Transparency
        myvalue=1- mysurf.getValue(SURFTRAN);
        mystring="d "+myvalue.asStr();
        pfile.writeln(STRING,mystring);
// IOR
        myvalue=mysurf.getValue(SURFRIND);
        mystring="Ni "+myvalue.asStr();
        pfile.writeln(STRING,mystring);
// Colourfilter/TransmissionFilter
        myvalue=mysurf.getValue(SURFCLRF);
        mystring="Tf "+myvalue.asStr();
        pfile.writeln(STRING,mystring);
// Reflection blurring
        myvalue=round(100*mysurf.getValue(SURFRBLR),0);
        mystring="sharpness "+myvalue.asStr();
        pfile.writeln(STRING,mystring);
// Maps

        pfile.writeln(STRING," ");

//colour
        mymap=getfirstimage(mysurf,SURFCOLR);
        if(mymap)
        {
            myimage=mymap.filename(0);
            mystring="map_Kd "+myimage;
            pfile.writeln(STRING,mystring);
        }

//ambient/Luminosity
        mymap=getfirstimage(mysurf,SURFLUMI);
        if(plum && mymap)
        {
            myimage=mymap.filename(0);
            mystring="map_Ka "+myimage;
            pfile.writeln(STRING,mystring);
        }

//Spec
        if(pchoice==1)
            mymap=getfirstimage(mysurf,SURFSPEC);
        else
            mymap=getfirstimage(mysurf,SURFREFL);

        if(mymap)
        {
            myimage=mymap.filename(0);
            mystring="map_Ks "+myimage;
            pfile.writeln(STRING,mystring);
        }

//Gloss
        mymap=getfirstimage(mysurf,SURFGLOS);
        if(mymap)
        {
            myimage=mymap.filename(0);
            mystring="map_Ns -imfchan l "+myimage;
            pfile.writeln(STRING,mystring);
        }

//Trans
        mymap=getfirstimage(mysurf,SURFTRAN);
        if(mymap)
        {
            myimage=mymap.filename(0);
            mystring="map_d -imfchan l "+myimage;
            pfile.writeln(STRING,mystring);
        }

//Bump
        mymap=getfirstimage(mysurf,SURFBUMP);
        if(mymap)
        {
            myimage=mymap.filename(0);
            mystring="map_bump -bmp l.0 "+myimage;
            pfile.writeln(STRING,mystring);
        }

//Refl  <================= LScript calls are buggy....
//debug();
//         if(mysurf.getValue(SURFRIMG))
//         {
//             mymap=mysurf.getValue(SURFRIMG);
//             myimage=mymap.filename(0);
//             mystring="refl -type sphere "+myimage;
//             pfile.writeln(STRING,mystring);
//         }

    }

}

replacespaces:pstring
{
        mynamebits=parse(" ",pstring);
        newname=mynamebits[1];
        for(i=2;i<=mynamebits.size();i++)
        {
            newname=newname+"_" + mynamebits[i];
        }

        return(newname);
}

getfirstimage:psurface,pchannel
{
//debug();
    myTOA=psurface.getTexture(pchannel);
    if(!myTOA)
        return(nil);
    mytexture=myTOA.firstLayer();
    while(mytexture && mytexture.type!=TXTRIMAGE && mytexture.getValue(TXLRIMAGE)==nil)
    {
        mytexture=myTOA.nextLayer(mytexture);
    }
    if(mytexture)
    {
        myimage=mytexture.getValue(TXLRIMAGE);
    }
    return(myimage);
}
